@@ -2,6 +2,8 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
+from compas.utilities import rgb_to_rgb
+
 from compas_ghpython import mesh_draw
 from compas_ghpython.geometry import xform_from_transformation
 
@@ -22,8 +24,10 @@ class RobotArtist(BaseRobotArtist):
         T = xform_from_transformation(transformation)
         native_mesh.Transform(T)
 
-    def draw_mesh(self, compas_mesh):
-        return mesh_draw(compas_mesh)
+    def draw_mesh(self, compas_mesh, color=None):
+        if color:
+            color = rgb_to_rgb(color[0], color[1], color[2])
+        return mesh_draw(compas_mesh, color=color)
 
     # def set_color(self, color_rgba):
     #     r, g, b, a = color_rgba
